Crate shape_ast

Crate shape_ast 

Re-exports

pub use data::Timeframe;
pub use data::TimeframeUnit;
pub use error::Result;
pub use error::ShapeError;
pub use error::SourceLocation;
pub use int_width::IntWidth;
pub use parser::parse_program;
pub use parser::resilient::ParseError;
pub use parser::resilient::ParseErrorKind;
pub use parser::resilient::PartialProgram;
pub use parser::resilient::parse_program_resilient;
pub use transform::desugar_program;
pub use ast::*;

Modules

ast
Abstract Syntax Tree definitions for Shape
data
Timeframe definitions and utilities
error
Unified error handling for Shape
int_width
IntWidth: shared width-semantics specification for first-class integer width types.
interpolation
Shared formatted-string interpolation parsing.
parser
Parser module for Shape language
transform
AST transformation module

Macros

parse_error
Helper macros for creating errors with location
require_args
Validates that exactly N arguments were passed to a function.
require_args_range
Validates that arguments count is within a range.
require_min_args
Validates that at least N arguments were passed to a function.
runtime_error
semantic_error