pub struct AsyncLetExpr {
pub name: String,
pub expr: Box<Expr>,
pub span: Span,
}Expand description
Async let expression: async let name = expr
Spawns a task and binds a future handle to a local variable.
Fields
name: StringThe variable name to bind the future handle to
expr: Box<Expr>The expression to spawn as an async task
span: SpanSpan covering the entire async let expression