Module functions

Module functions 

Function definition and parameter types for Shape AST

Re-exports

pub use super::types::TypeParam;

Structs

Annotation
AnnotationDef
Annotation definition with lifecycle hooks
AnnotationHandler
A lifecycle handler within an annotation definition
AnnotationHandlerParam
ForeignFunctionDef
A foreign function definition: fn <language> name(params) -> type { foreign_body }
FunctionDef
FunctionParameter
NativeAbiBinding
Native ABI link metadata attached to a foreign function declaration.

Enums

AnnotationHandlerType
Type of annotation lifecycle handler
AnnotationTargetKind
Describes what kind of syntax element an annotation is targeting. Used for compile-time validation of annotation applicability.