pub struct FunctionDef {
pub name: String,
pub name_span: Span,
pub declaring_module_path: Option<String>,
pub doc_comment: Option<DocComment>,
pub type_params: Option<Vec<TypeParam>>,
pub params: Vec<FunctionParameter>,
pub return_type: Option<TypeAnnotation>,
pub where_clause: Option<Vec<WherePredicate>>,
pub body: Vec<Statement>,
pub annotations: Vec<Annotation>,
pub is_async: bool,
pub is_comptime: bool,
}Fields
name: Stringname_span: Spandeclaring_module_path: Option<String>Declaring module path for compiler/runtime provenance checks.
This is injected by the module loader for loaded modules and is not part of user-authored source syntax.
doc_comment: Option<DocComment>type_params: Option<Vec<TypeParam>>params: Vec<FunctionParameter>return_type: Option<TypeAnnotation>where_clause: Option<Vec<WherePredicate>>body: Vec<Statement>annotations: Vec<Annotation>is_async: boolis_comptime: boolWhether this function is compile-time-only (comptime fn).
Comptime-only functions can only be called from comptime contexts.