pub struct FunctionParameter {
pub pattern: DestructurePattern,
pub is_const: bool,
pub is_reference: bool,
pub is_mut_reference: bool,
pub is_out: bool,
pub type_annotation: Option<TypeAnnotation>,
pub default_value: Option<Expr>,
}Fields
pattern: DestructurePatternis_const: boolis_reference: boolis_mut_reference: boolWhether this is an exclusive (mutable) reference: &mut x
Only meaningful when is_reference is true.
is_out: boolWhether this is an out parameter (C out-pointer pattern).
Only valid on extern C fn declarations. The compiler auto-generates
cell allocation, C call, value readback, and cell cleanup.
type_annotation: Option<TypeAnnotation>default_value: Option<Expr>Implementations
Sourceimpl FunctionParameter
impl FunctionParameter
Sourcepub fn simple_name(&self) -> Option<&str>
pub fn simple_name(&self) -> Option<&str>
Get the simple parameter name if this is a simple identifier pattern
Sourcepub fn get_identifiers(&self) -> Vec<String>
pub fn get_identifiers(&self) -> Vec<String>
Get all identifiers bound by this parameter (for destructuring patterns)