Module types

Module types 

Type system definitions for Shape AST

Structs

AssociatedTypeBinding
A concrete binding for an associated type inside an impl block: type Item = number;
EnumDef
EnumMember
ExtendStatement
Type extension for adding methods to existing types
FunctionParam
ImplBlock
Impl block — implements a trait for a type
MethodDef
NativeLayoutBinding
Native layout binding metadata for type C declarations.
ObjectTypeField
StructField
A field in a struct type definition
StructTypeDef
Struct type definition — pure data with named fields
TraitDef
Trait definition — supports required signatures and default methods.
TypeAliasDef
WherePredicate
A predicate in a where clause: T: Comparable + Display

Enums

EnumMemberKind
EnumValue
TraitMember
A member of a trait definition: either required (signature only) or default (with body)
TraitMemberSignature
A body-less trait member signature: property, method, or index signature.
TypeAnnotation
TypeName
TypeParam
A generic parameter on a function, type, trait or impl header.