pub enum InterpolationFormatSpec {
Fixed {
precision: u8,
},
Table(TableFormatSpec),
ContentStyle(ContentFormatSpec),
}Expand description
Typed format specification for interpolation expressions.
Variants
Fixed
Fixed-point numeric precision (fixed(2)).
Table(TableFormatSpec)
Tabular formatting for DataTable-like values (table(...)).
ContentStyle(ContentFormatSpec)
Content-styling specification (R8 W4 W18.4 — supervisor 2026-05-24
D1 + (a-modified) REVIVE-WITH-SHARED-MODULE). Parsed from f-string
styling syntax like {x:bold,red} / {x:fg(blue),italic}.
The presence of this variant in any interpolation part flips the
f-string’s return type from string to content per D1’s
syntax-determined rule.