parse_window_from_function_call

Function parse_window_from_function_call 

pub fn parse_window_from_function_call(
    name: String,
    args: Vec<Expr>,
    over_pair: Pair<'_, Rule>,
    span: Span,
) -> Result<Expr>
Parse window function from a regular function call that has an OVER clause This is called when we detect a function call followed by OVER