pub fn parse_string_literal_with_kind(raw: &str) -> Result<ParsedStringLiteral>Expand description
Decode a parsed string literal and report whether it used the f prefix.
pub fn parse_string_literal_with_kind(raw: &str) -> Result<ParsedStringLiteral>Decode a parsed string literal and report whether it used the f prefix.