Function definition and parameter types for Shape AST
Re-exports
pub use super::types::TypeParam;
Structs
- Annotation
- Annotation
Def - Annotation definition with lifecycle hooks
- Annotation
Handler - A lifecycle handler within an annotation definition
- Annotation
Handler Param - Foreign
Function Def - A foreign function definition:
fn <language> name(params) -> type { foreign_body } - Function
Def - Function
Parameter - Native
AbiBinding - Native ABI link metadata attached to a foreign function declaration.
Enums
- Annotation
Handler Type - Type of annotation lifecycle handler
- Annotation
Target Kind - Describes what kind of syntax element an annotation is targeting. Used for compile-time validation of annotation applicability.