Type system definitions for Shape AST
Structs
- Associated
Type Binding - A concrete binding for an associated type inside an
implblock:type Item = number; - EnumDef
- Enum
Member - Extend
Statement - Type extension for adding methods to existing types
- Function
Param - Impl
Block - Impl block — implements a trait for a type
- Method
Def - Native
Layout Binding - Native layout binding metadata for
type Cdeclarations. - Object
Type Field - Struct
Field - A field in a struct type definition
- Struct
Type Def - Struct type definition — pure data with named fields
- Trait
Def - Trait definition — supports required signatures and default methods.
- Type
Alias Def - Where
Predicate - A predicate in a where clause:
T: Comparable + Display
Enums
- Enum
Member Kind - Enum
Value - Trait
Member - A member of a trait definition: either required (signature only) or default (with body)
- Trait
Member Signature - A body-less trait member signature: property, method, or index signature.
- Type
Annotation - Type
Name - Type
Param - A generic parameter on a function, type, trait or impl header.