Type system definitions for Shape AST
Structs
- Associated
Type Binding - A concrete binding for an associated type inside an
implblock:type Item = number; - EnumDef
- Enum
Member - Extend
Statement - Type extension for adding methods to existing types
- Function
Param - Impl
Block - Impl block — implements a trait for a type
- Interface
Def - Method
Def - Native
Layout Binding - Native layout binding metadata for
type Cdeclarations. - Object
Type Field - Struct
Field - A field in a struct type definition
- Struct
Type Def - Struct type definition — pure data with named fields
- Trait
Def - Trait definition — like interface but with
traitkeyword, supporting default methods - Type
Alias Def - Where
Predicate - A predicate in a where clause:
T: Comparable + Display
Enums
- Enum
Member Kind - Enum
Value - Interface
Member - Trait
Member - A member of a trait definition: either required (signature only) or default (with body)
- Type
Annotation - Type
Name - Type
Param - A generic parameter on a function, type, trait or impl header.