Control flow expression parsing
This module handles parsing of control flow expressions:
- If/else expressions (conditionals)
- While loops (loops)
- For loops (loops)
- Infinite loops (loops)
- Let expressions (loops)
- Match expressions (pattern_matching)
- Try/catch expressions (conditionals)
- Break/continue/return (loops)
- Block expressions (loops)
- Pattern matching (pattern_matching)
- LINQ-style query expressions (this module)
Functions
- parse_
async_ let_ expr - Parse async let expression:
async let name = exprSpawns a task and binds a future handle to a local variable. - parse_
async_ scope_ expr - Parse async scope expression:
async scope { ... }Cancellation boundary – on scope exit, all pending tasks are cancelled in reverse order. - parse_
block_ expr - Parse block expression
- parse_
break_ expr - Parse break expression
- parse_
for_ expr - Parse for expression (including
for await x in stream { }) - parse_
from_ query_ expr - Parse LINQ-style from query expression Syntax: from var in source [clauses…] select expr
- parse_
if_ expr - Parse if expression
- parse_
let_ expr - Parse let expression
- parse_
loop_ expr - Parse loop expression
- parse_
match_ expr - Parse match expression
- parse_
pattern - Parse pattern
- parse_
return_ expr - Parse return expression
- parse_
while_ expr - Parse while expression