Window function expression parser
Parses window function expressions like:
lag(close, 1) over (partition by symbol order by timestamp)row_number() over (order by close desc)sum(volume) over (rows between 5 preceding and current row)
Functions
- parse_
window_ from_ function_ call - Parse window function from a regular function call that has an OVER clause This is called when we detect a function call followed by OVER
- parse_
window_ function_ call - Parse a window function call expression